#!/usr/bin/python

import unittest

from CommandNotFound.CommandNotFound import BinaryDatabase


class RegressionTestCase(unittest.TestCase):

    def test_lp1130444(self):
        db = BinaryDatabase("")
        db.db = {'foo': 'bar'}
        self.assertEqual(db.lookup("foo\udcb6"), None)
